@@ -40,4 +40,4 @@ void click_edit_widgets_button( ){
 
 ////////////////////////////////////////////////////////////////////////// BUTTON
 
-s_button button_edit_widgets = {"edit widgets", "/apps/asui_state/bcell_edit_widgets", draw_edit_widgets_button, click_edit_widgets_button, 0};
+s_button button_edit_widgets = {"#widgets", "/apps/asui_state/bcell_edit_widgets", draw_edit_widgets_button, click_edit_widgets_button, 0};
