@@ -27,6 +27,7 @@ const char *conf_brightness_level = "/apps/asui_state/brightness_level";
 const char *conf_theme = "/apps/asui_state/theme";
 const char *conf_ssh_server = "/apps/asui_state/ssh_server";
 const char *conf_battery_usage = "/apps/asui_state/battery_usage";
+const char *conf_screenshot_delay = "/apps/asui_state/screenshot_delay";
 
 const char *conf_alarm_open = "/apps/asui_state/alarm_open";
 const char *conf_alarm_tklock = "/apps/asui_state/alarm_tklock";
@@ -51,17 +52,17 @@ unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
 // BRV keys
 unsigned cfg_buttons_rotate, cfg_buttons_brightness, cfg_buttons_brightness_step, cfg_buttons_volume, cfg_buttons_volume_step;
 // button modes
-unsigned cfg_double_tap, cfg_lock_and_close, cfg_n800_lock_mode, cfg_rotate_and_close;
+unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close;
 unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short, cfg_buttons_lock1_long, cfg_buttons_lock2_short, cfg_buttons_lock2_long;
 unsigned cfg_secure_action, cfg_secure_power_action, cfg_secure_button;
-unsigned cfg_power_unlock_key;
+unsigned cfg_power_action, cfg_power_unlock_key;
 // user interface
 unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
 // alarm
 unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max, cfg_alarm_volume_step;
 
 // state
-unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage;
+unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
 
 ////////////////////////////////////////////////////////////////////////// WIDGETS
 
@@ -90,13 +91,14 @@ extern s_button button_rotate1;
 extern s_button button_rotate2;
 extern s_button button_rotate3;
 extern s_button button_key_repeat;
+extern s_button button_screenshot;
 extern s_button button_screen_stayslit;
 extern s_button button_screen_autolock;
 extern s_button button_settings;
+extern s_button button_edit_buttons;
 extern s_button button_edit_widgets;
 
-s_button *landscape_bcells[MAX_BUTTON_CELLS];
-s_button *portrait_bcells[MAX_BUTTON_CELLS];
+s_button *button_cells[MAX_BUTTON_CELLS];
 
 //////////////////////////////////////////////////////////////////////////
 
@@ -130,7 +132,6 @@ static const char *conf_buttons_volume_step = "/apps/asui/buttons_volume_step";
 // button modes
 static const char *conf_double_tap = "/apps/asui/double_tap";
 static const char *conf_lock_and_close = "/apps/asui/lock_and_close";
-static const char *conf_n800_lock_mode = "/apps/asui/n800_lock_mode";
 static const char *conf_rotate_and_close = "/apps/asui/rotate_and_close";
 static const char *conf_buttons_dpad_short = "/apps/asui/buttons_dpad_short";
 static const char *conf_buttons_dpad_long = "/apps/asui/buttons_dpad_long";
@@ -141,6 +142,7 @@ static const char *conf_buttons_lock2_long = "/apps/asui/buttons_lock2_long";
 static const char *conf_secure_action = "/apps/asui/secure_action";
 static const char *conf_secure_power_action = "/apps/asui/secure_power_action";
 static const char *conf_secure_button = "/apps/asui/secure_button";
+static const char *conf_power_action = "/apps/asui/power_action";
 static const char *conf_power_unlock_key = "/apps/asui/power_unlock_key";
 // user interface
 static const char *conf_tkactive_notifications = "/apps/asui/tkactive_notifications";
@@ -221,37 +223,68 @@ static void make_float( float *variable, const char *key, float initial_value, u
 
 ////////////////////////////////////////////////////////////////////////// BUTTON CELLS
 
-static unsigned load_button( s_button *button, unsigned initial_cell, unsigned force_initial ){
-	landscape_bcells[initial_cell] = button;
-	portrait_bcells[initial_cell] = button;
+static s_button *button_queue[MAX_BUTTON_CELLS];
+static unsigned button_index;
 
-	return 1;
+static void load_button( s_button *button, unsigned initial_cell, unsigned force_initial ){
+	unsigned cell;
+	if(force_initial){
+		// cells are corrupt, use initial values
+		cell = initial_cell;
+		conf_set_int(button->conf, cell);
+	} else {
+		// create gconf key or fetch previous value for cell location
+		make_uint(&cell, button->conf, initial_cell, 0);
+	}
+
+	if(button_cells[cell]){
+		// another button is already in this cell, add to queue and randomly place it later
+		button_queue[button_index] = button;
+		button_index++;
+	} else {
+		// add widget to landscape and portrait orientations
+		button_cells[cell] = button;
+		button->cell = cell;
+	}
 }
 
-static unsigned load_buttons( unsigned force_initial ){
+static void load_buttons( unsigned force_initial ){
 	int i;
 	for(i = 0; i < MAX_BUTTON_CELLS; i++){
-		landscape_bcells[i] = NULL;
-		portrait_bcells[i] = NULL;
+		button_cells[i] = NULL;
+		button_queue[i] = NULL;
 	}
-	if(!load_button(&button_lock1,				 0, force_initial)) return 0;
-	if(!load_button(&button_lock2,				 1, force_initial)) return 0;
-	if(!load_button(&button_flight_mode,		 2, force_initial)) return 0;
-	if(!load_button(&button_reboot,				 4, force_initial)) return 0;
-	if(!load_button(&button_shutdown,			 5, force_initial)) return 0;
-	if(!load_button(&button_rotate1,			 7, force_initial)) return 0;
-	if(!load_button(&button_rotate2,			 8, force_initial)) return 0;
-	if(!load_button(&button_rotate3,			 9, force_initial)) return 0;
-	if(!load_button(&button_key_repeat,			10, force_initial)) return 0;
-	if(!load_button(&button_screen_stayslit,	14, force_initial)) return 0;
-	if(!load_button(&button_screen_autolock,	15, force_initial)) return 0;
-	if(!load_button(&button_settings,			17, force_initial)) return 0;
-	if(!load_button(&button_edit_widgets,		19, force_initial)) return 0;
+	button_index = 0;
 
-// TODO: any new buttons MUST use an automatic placement technique unless force_initial is set
-// TODO: add a function that scans for an empty cell in both orientations and returns the value, call when !force_initial
+	load_button(&button_lock1,				 0, force_initial);
+	load_button(&button_lock2,				 1, force_initial);
+	load_button(&button_flight_mode,		 2, force_initial);
+	load_button(&button_reboot,				 4, force_initial);
+	load_button(&button_shutdown,			 5, force_initial);
+	load_button(&button_rotate1,			 7, force_initial); // hw_refresh() needs the rotation buttons to stay on primary page so it can call check_orientation()
+	load_button(&button_rotate2,			 8, force_initial); // hw_refresh() needs the rotation buttons to stay on primary page so it can call check_orientation()
+	load_button(&button_rotate3,			 9, force_initial); // hw_refresh() needs the rotation buttons to stay on primary page so it can call check_orientation()
 
-	return 1;
+	load_button(&button_key_repeat,			10, force_initial);
+	load_button(&button_screenshot,			12, force_initial);
+	load_button(&button_screen_stayslit,	14, force_initial);
+	load_button(&button_screen_autolock,	15, force_initial);
+	load_button(&button_settings,			17, force_initial);
+	load_button(&button_edit_buttons,		18, force_initial);
+	load_button(&button_edit_widgets,		19, force_initial);
+
+	// find empty cells for homeless buttons
+	while(button_index){
+		button_index--;
+		s_button *button = button_queue[button_index];
+		int i;
+		for(i = MAX_BUTTON_CELLS-1; i >= 0; i--)
+			if(button_cells[i] == NULL){
+				button_cells[i] = button;
+				button->cell = i;
+				conf_set_int(button->conf, i);
+			}
+	}
 }
 
 ////////////////////////////////////////////////////////////////////////// WIDGET CELLS
@@ -376,7 +409,6 @@ void config_init( ){
 	// button modes
 	gconf_client_unset(gconf_client, conf_double_tap, NULL);
 	gconf_client_unset(gconf_client, conf_lock_and_close, NULL);
-	gconf_client_unset(gconf_client, conf_n800_lock_mode, NULL);
 	gconf_client_unset(gconf_client, conf_rotate_and_close, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_dpad_short, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_dpad_long, NULL);
@@ -387,6 +419,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_secure_action, NULL);
 	gconf_client_unset(gconf_client, conf_secure_power_action, NULL);
 	gconf_client_unset(gconf_client, conf_secure_button, NULL);
+	gconf_client_unset(gconf_client, conf_power_action, NULL);
 	gconf_client_unset(gconf_client, conf_power_unlock_key, NULL);
 	// user interface
 	gconf_client_unset(gconf_client, conf_tkactive_notifications, NULL);
@@ -412,6 +445,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, button_rotate2.conf, NULL);
 	gconf_client_unset(gconf_client, button_rotate3.conf, NULL);
 	gconf_client_unset(gconf_client, button_key_repeat.conf, NULL);
+	gconf_client_unset(gconf_client, button_screenshot.conf, NULL);
 	gconf_client_unset(gconf_client, button_screen_stayslit.conf, NULL);
 	gconf_client_unset(gconf_client, button_screen_autolock.conf, NULL);
 	gconf_client_unset(gconf_client, button_settings.conf, NULL);
@@ -433,6 +467,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_theme, NULL);
 	gconf_client_unset(gconf_client, conf_ssh_server, NULL);
 	gconf_client_unset(gconf_client, conf_battery_usage, NULL);
+	gconf_client_unset(gconf_client, conf_screenshot_delay, NULL);
 	gconf_client_unset(gconf_client, "/apps/asui_state", NULL);
 
 	printf("all gconf keys cleared\n");
@@ -442,17 +477,23 @@ void config_init( ){
 	// key no longer used, remove it
 	gconf_client_unset(gconf_client, "/apps/asui/no_save_unders", NULL); // removed in 0.2.8
 	gconf_client_unset(gconf_client, "/apps/asui/brightness_level", NULL); // removed in 0.4.5
+	gconf_client_unset(gconf_client, "/apps/asui/n800_lock_mode", NULL); // removed in 0.5.7
+	gconf_client_unset(gconf_client, "/apps/asui/softpoweroff_mode", NULL); // added and removed in 0.5.7 test releases
 
 	first_config_load = 1;
 	config_reload();
 	first_config_load = 0;
 
 	// initialize button cells
-	if(!load_buttons(0)){
-		error_write("button cells are corrupted, reverting to defaults");
-		if(!load_buttons(1)){
-			error_write("button cells are corrupted AND THE DEFAULTS ARE BAD TOO!!!");
-			exit(EXIT_FAILURE);
+	load_buttons(0);
+	// hw_refresh() needs the rotation buttons to stay on primary page so it can call check_orientation()
+	{
+		int i, revert_buttons = 0;
+		for(i = 10; i < MAX_BUTTON_CELLS; i++)
+			if(button_cells[i] == &button_rotate1 || button_cells[i] == &button_rotate2 || button_cells[i] == &button_rotate3) revert_buttons = 1;
+		if(revert_buttons){
+			error_write("button cells are corrupted, reverting to defaults");
+			load_buttons(1);
 		}
 	}
 
@@ -526,7 +567,6 @@ void config_reload( ){
 	// button modes
 	make_bool(&cfg_double_tap,				conf_double_tap,				1,		0);					// default: 1	require double taps where available
 	make_bool(&cfg_lock_and_close,			conf_lock_and_close,			1,		0);					// default: 1	close window after using on-screen lock buttons
-	make_bool(&cfg_n800_lock_mode,			conf_n800_lock_mode,			!is_810,0);					// default: -	enabled for n800/770
 	make_bool(&cfg_rotate_and_close,		conf_rotate_and_close,			1,		0);					// default: 1	close window after using on-screen rotation buttons
 	make_uint(&cfg_buttons_dpad_short,		conf_buttons_dpad_short,		1,		0);					// default: 0	lock
 	make_uint(&cfg_buttons_dpad_long,		conf_buttons_dpad_long,			4,		0);					// default: 0	secure
@@ -537,6 +577,7 @@ void config_reload( ){
 	make_uint(&cfg_secure_action,			conf_secure_action,				2,		0);					// default: 0	lock&blank
 	make_uint(&cfg_secure_power_action,		conf_secure_power_action,		1,		0);					// default: 0	lock&blank
 	make_bool(&cfg_secure_button,			conf_secure_button,				0,		HW_THEME);			// default: 0	don't show secure button
+	make_uint(&cfg_power_action, 			conf_power_action,			(is_810 ? 2:1),	0);				// default: -	open/close for n810, open-only for n800/770
 	make_uint(&cfg_power_unlock_key,		conf_power_unlock_key,		(is_810 ? 1:4),	0);				// default: 1/4	power button + fullscreen/dpad key unlocks
 	// user interface
 	make_bool(&cfg_tkactive_notifications,	conf_tkactive_notifications,	1,		0);					// default: 1	show screen on unlock notifications
@@ -557,6 +598,7 @@ void config_reload( ){
 	make_uint(&cfg_theme,					conf_theme,						theme,	HW_THEME);			// default: 0/1	color theme
 	make_uint(&cfg_ssh_server,				conf_ssh_server,				0,		HW_BRIGHTNESS);		// default: 0	openssh
 	make_bool(&cfg_battery_usage,			conf_battery_usage,				0,		HW_BATTERY);		// default: 0	show active/idle times
+	make_uint(&cfg_screenshot_delay,		conf_screenshot_delay,			5,		HW_THEME);			// default: 5	5 seconds
 
 	// memory and swap formats can be 0-3
 	if(cfg_memory_format > 3){ cfg_memory_format = 0; conf_set_int(conf_memory_format, 0); }
@@ -621,9 +663,10 @@ void config_reload( ){
 	if(cfg_buttons_lock1_long > 4){ cfg_buttons_lock1_long = 0; conf_set_int(conf_buttons_lock1_long, 0); } // disable if invalid
 	if(cfg_buttons_lock2_short > 4){ cfg_buttons_lock2_short = 0; conf_set_int(conf_buttons_lock2_short, 0); } // disable if invalid
 	if(cfg_buttons_lock2_long > 4){ cfg_buttons_lock2_long = 0; conf_set_int(conf_buttons_lock2_long, 0); } // disable if invalid
-	if(cfg_secure_action > 3){ cfg_secure_action = 0; conf_set_int(conf_secure_action, 0); } // disable if invalid
-	if(cfg_secure_power_action > 2){ cfg_secure_power_action = 0; conf_set_int(conf_secure_power_action, 0); } // disable if invalid
-	if(cfg_power_unlock_key > 5){ cfg_power_unlock_key = 1; conf_set_int(conf_power_unlock_key, 1); } // set to fullscreen if invalid
+	if(cfg_secure_action > 3){ cfg_secure_action = 2; conf_set_int(conf_secure_action, 2); } // revert to default if invalid
+	if(cfg_secure_power_action > 2){ cfg_secure_power_action = 1; conf_set_int(conf_secure_power_action, 1); } // revert to default if invalid
+	if(cfg_power_action > 2){ cfg_power_action = (is_810 ? 2:1); conf_set_int(conf_power_action, cfg_power_action); } // revert to default if invalid
+	if(cfg_power_unlock_key > 5){ cfg_power_unlock_key = (is_810 ? 1:4); conf_set_int(conf_power_unlock_key, cfg_power_unlock_key); } // revert to default if invalid
 
 // override until 770 is supported
 if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_bool(conf_brightness_enhanced, 0); } // disable
@@ -645,6 +688,8 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	// make sure theme is valid
 	if(cfg_theme > 2){ cfg_theme = 1; conf_set_int(conf_theme, 1); } // reset to black theme
 
+	if(cfg_screenshot_delay < MIN_SCREENSHOT_DELAY || cfg_screenshot_delay > MAX_SCREENSHOT_DELAY){ cfg_screenshot_delay = 5; conf_set_int(conf_screenshot_delay, 5); } // reset
+
 	if(!first_config_load){
 		// re-initialize brightness when changed
 		if(cfg_brightness_enhanced != prev_brightness_enhanced)
@@ -692,6 +737,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	cfg_theme = 1; // no ALS sensor, use blank theme
 	cfg_ssh_server = 0; // openssh
 	cfg_battery_usage = 0; // show active/idle times
+	cfg_screenshot_delay = 5;
 
 	#endif
 
@@ -726,7 +772,6 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	// button modes
 	debug_write("  cfg_double_tap = %u", cfg_double_tap);
 	debug_write("  cfg_lock_and_close = %u", cfg_lock_and_close);
-	debug_write("  cfg_n800_lock_mode = %u", cfg_n800_lock_mode);
 	debug_write("  cfg_rotate_and_close = %u", cfg_rotate_and_close);
 	debug_write("  cfg_buttons_dpad_short = %u", cfg_buttons_dpad_short);
 	debug_write("  cfg_buttons_dpad_long = %u", cfg_buttons_dpad_long);
@@ -737,6 +782,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_secure_action = %u", cfg_secure_action);
 	debug_write("  cfg_secure_power_action = %u", cfg_secure_power_action);
 	debug_write("  cfg_secure_button = %u", cfg_secure_button);
+	debug_write("  cfg_power_action = %u", cfg_power_action);
 	debug_write("  cfg_power_unlock_key = %u", cfg_power_unlock_key);
 	// user interface
 	debug_write("  cfg_tkactive_notifications = %u", cfg_tkactive_notifications);
@@ -757,6 +803,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_theme = %u", cfg_theme);
 	debug_write("  cfg_ssh_server = %u", cfg_ssh_server);
 	debug_write("  cfg_battery_usage = %u", cfg_battery_usage);
+	debug_write("  cfg_screenshot_delay = %u", cfg_screenshot_delay);
 	debug_write("------------------------------");
 }
 
