@@ -14,6 +14,7 @@ extern const char *conf_brightness_level;
 extern const char *conf_theme;
 extern const char *conf_ssh_server;
 extern const char *conf_battery_usage;
+extern const char *conf_screenshot_delay;
 
 extern const char *conf_alarm_open;
 extern const char *conf_alarm_tklock;
@@ -38,22 +39,27 @@ extern unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
 // BRV keys
 extern unsigned cfg_buttons_rotate, cfg_buttons_brightness, cfg_buttons_brightness_step, cfg_buttons_volume, cfg_buttons_volume_step;
 // button modes
-extern unsigned cfg_double_tap, cfg_lock_and_close, cfg_n800_lock_mode, cfg_rotate_and_close;
+extern unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close;
 extern unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short, cfg_buttons_lock1_long, cfg_buttons_lock2_short, cfg_buttons_lock2_long;
 extern unsigned cfg_secure_action, cfg_secure_power_action, cfg_secure_button;
-extern unsigned cfg_power_unlock_key;
+extern unsigned cfg_power_action, cfg_power_unlock_key;
 // user interface
 extern unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
 // alarm
 extern unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max, cfg_alarm_volume_step;
 
 // state
-extern unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage;
+extern unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
 
 #define CFG_BUTTONS_ZOOM 1
 #define CFG_BUTTONS_UD 2
 #define CFG_BUTTONS_LR 3
 
+enum { POWER_ACTION_LOCKBLANK = 0, POWER_ACTION_OPEN, POWER_ACTION_OPENCLOSE };
+
+#define MIN_SCREENSHOT_DELAY 1
+#define MAX_SCREENSHOT_DELAY 20
+
 //////////////////////////////////////////////////////////////////////////
 
 typedef enum e_widget_size { EMPTY_CELL, FULL_WIDGET, HALF_WIDGET } e_widget_size;
@@ -88,8 +94,7 @@ typedef struct s_button {
 } s_button;
 
 #define MAX_BUTTON_CELLS 20
-extern s_button *landscape_bcells[MAX_BUTTON_CELLS];
-extern s_button *portrait_bcells[MAX_BUTTON_CELLS];
+extern s_button *button_cells[MAX_BUTTON_CELLS];
 
 //////////////////////////////////////////////////////////////////////////
 
