@@ -50,6 +50,10 @@ static const char *_notification_path_ = "/org/freedesktop/Notifications";
 static const char *_notification_interface_ = "org.freedesktop.Notifications";
 static const char *_notification_method_ = "SystemNoteInfoprint"; // method
 
+static const char *_osso_multimedia_service_ = "com.nokia.osso_media_server";
+static const char *_osso_multimedia_path_ = "/com/nokia/osso_media_server";
+static const char *_osso_multimedia_interface_ = "com.nokia.osso_media_server.sound";
+
 static unsigned acting_dead_state;
 //static unsigned powerkeymenu_open;
 #endif
@@ -393,11 +397,14 @@ debug_write("PB: screen has been on for more than one second, tklock=%u, asui=%u
 								usleep(100000); // sleep 20 x 100ms until screen dims
 							}
 							mce_lock_and_blank_screen();
+						} else if(cfg_power_action == POWER_ACTION_LOCKBLANK){
+							// lock&blank screen instead of mapping or unmapping ASUI
+							mce_lock_and_blank_screen();
 						} else if(window.is_mapped){
 							if(hw_device_locked){
 								// device is locked, power button will invoke the secure_power_action
 								press_lock_button(cfg_secure_power_action+1);
-							} else if(!cfg_n800_lock_mode){
+							} else if(cfg_power_action == POWER_ACTION_OPENCLOSE){
 								// unmap ASUI unless n800_lock_mode is enabled
 								dbus_send_wakeup(_WAKEUP_HIDE_);
 							}
@@ -541,7 +548,10 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 					// screen was just unlocked
 					notify_screen_unlocked();
 				}
-				hw_unlock_keys(); // always make sure keypad is unlocked, even if ASUI doesn't think the screen is locked
+
+				// always make sure screen/keypad is unlocked
+				hw_unlock_screen();
+				hw_unlock_keys();
 				hw_screen.locked = 0;
 			} else if(!strcmp(s1, "locked")){
 				debug_write("[DBUS] signal: com.nokia.mce.signal.tklock_mode_ind (lock)");
@@ -550,7 +560,9 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 					// screen was just locked but is still visible
 					notify_screen_locked();
 				}
-				hw_lock_keys(); // always make sure keypad is locked, even if ASUI doesn't think the screen is unlocked
+				// always make sure screen/keypad is locked
+				hw_lock_screen();
+				hw_lock_keys();
 				hw_screen.locked = 1;
 
 				window_close_blank(); // close the blank window, if open
@@ -650,6 +662,8 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 
 		debug_write("[DBUS] signal: com.nokia.mce.signal.shutdown_ind");
 
+		hw_restore_cp_screen_settings();
+
 		dbus_send_wakeup(_WAKEUP_SHUTDOWN_);
 
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -712,6 +726,8 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 			dbus_send_charging_status_signal();
 			if(is_value_visible(battery_widget_page)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 
+			hw_new_event("charger", &hw_battery.charger_history_head, &hw_battery.charger_history_tail, 1);
+
 			hw_query_battery(1); // flush
 		}
 
@@ -729,6 +745,8 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 			dbus_send_charging_status_signal();
 			if(is_value_visible(battery_widget_page)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 
+			hw_new_event("charger", &hw_battery.charger_history_head, &hw_battery.charger_history_tail, 0);
+
 			hw_query_battery(1); // flush
 		}
 
@@ -738,6 +756,9 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 
 		debug_write("[DBUS] signal: com.nokia.bme.signal.charger_charging_on");
 
+		if(hw_battery.status == BATTERY_DRAINING)
+			hw_new_event("charger", &hw_battery.charger_history_head, &hw_battery.charger_history_tail, 1);
+
 		set_battery_status(BATTERY_CHARGING);
 
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -758,11 +779,13 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 
 		return DBUS_HANDLER_RESULT_HANDLED;
 
-//	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "battery_empty")){
+	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "battery_empty")){
 
 		// signature = <none>
 		// device shuts down after receiving this
 
+		hw_restore_cp_screen_settings();
+
 	////////////////////
 	// BLUEZ
 	} else if(dbus_message_is_signal(message, "org.bluez.Adapter", "ModeChanged")){
@@ -1105,6 +1128,7 @@ static void *dbus_thread( void *arg ){
 		dbus_bus_add_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal',member='charger_charging_on'", &dbus_error);
 		dbus_bus_add_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal',member='charger_charging_off'", &dbus_error);
 		dbus_bus_add_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal',member='battery_full'", &dbus_error);
+		dbus_bus_add_match(signal_bus, "type='signal',path='/com/nokia/bme/signal',interface='com.nokia.bme.signal',member='battery_empty'", &dbus_error);
 
 		// bluez signals (bluetooth status)
 		dbus_bus_add_match(signal_bus, "type='signal',path='/org/bluez/hci0',interface='org.bluez.Adapter',member='ModeChanged'", &dbus_error);
@@ -1346,6 +1370,32 @@ void notify_blanking_pause2( ){
 	#endif
 }
 
+////////////////////////////////////////////////////////////////////////// SOUNDS
+
+void dbus_audio_set_volume( double volume ){
+	#ifdef ARCH_armel
+	dbus_send_session_method(_osso_multimedia_service_, _osso_multimedia_path_, _osso_multimedia_interface_, "set_volume", _DOUBLE_, &volume, _END_);
+	#endif
+}
+
+void dbus_audio_set_loop( unsigned loop ){
+	#ifdef ARCH_armel
+	dbus_send_session_method(_osso_multimedia_service_, _osso_multimedia_path_, _osso_multimedia_interface_, "set_loop", _BOOL_, &loop, _END_);
+	#endif
+}
+
+void dbus_audio_play( char *sound, int priority ){
+	#ifdef ARCH_armel
+	dbus_send_session_method(_osso_multimedia_service_, _osso_multimedia_path_, _osso_multimedia_interface_, "play_sound", _STRING_, &sound, _INT32_, &priority, _END_);
+	#endif
+}
+
+void dbus_audio_stop( ){
+	#ifdef ARCH_armel
+	dbus_send_session_method(_osso_multimedia_service_, _osso_multimedia_path_, _osso_multimedia_interface_, "stop", _END_);
+	#endif
+}
+
 ////////////////////////////////////////////////////////////////////////// STATUSBAR APPLET SIGNALS
 
 void dbus_send_charging_status_signal( ){
