@@ -75,6 +75,11 @@ void notify_power_unlock_key( );
 void notify_blanking_pause1( );
 void notify_blanking_pause2( );
 
+void dbus_audio_set_volume( double volume );
+void dbus_audio_set_loop( unsigned loop );
+void dbus_audio_play( char *sound, int priority );
+void dbus_audio_stop( );
+
 void dbus_send_charging_status_signal( );
 void dbus_send_battery_capacity_signal( );
 
