@@ -386,6 +386,19 @@ void mce_init( ){
 
 ////////////////////
 
+void hw_restore_cp_screen_settings( ){
+	if(original_screen_autolock){
+		// restored scree_autolock setting
+		conf_set_screen_autolock_value(original_screen_autolock-1);
+		original_screen_autolock = 0;
+	}
+	if(original_screen_stayslit){
+		// restore screen_stayslit setting
+		conf_set_screen_stayslit_value(original_screen_stayslit-1);
+		original_screen_stayslit = 0;
+	}
+}
+
 void mce_wake_screen( ){
 	#ifdef ARCH_armel
 	dbus_send_method(_mce_service_, _mce_path_, _mce_interface_, "req_display_state_on", _END_);
@@ -638,7 +651,6 @@ static void bme_update_drain( ){
 	}
 	if(current_time > timestamp + 5401.0){ // wait 1.5 hours
 		float hours = (current_time - timestamp) / 3600.0;
-		if(hours > 24.0) hours = 24.0;
 		hw_battery.hours24 = roundf(hours);
 		hw_battery.drain24 = roundf(10.0 * (capacity - current_capacity) / hours)/10.0;
 	} else {
@@ -739,6 +751,37 @@ static void bme_get_active_callback( DBusPendingCall *pending, void *user_data )
 }
 #endif
 
+#ifdef TESTLOG
+static double base_time;
+static void new_battcap( double timestamp, float capacity ){
+	if(cfg_history_days == 0) return;
+
+	s_battery_history *history = (s_battery_history *)malloc(sizeof(s_battery_history));
+	if(history){
+		history->timestamp = base_time + timestamp;
+		history->capacity = capacity;
+		history->prev = hw_battery.history_tail;
+		history->next = NULL;
+
+		if(hw_battery.history_head == NULL)
+			hw_battery.history_head = history;
+		else {
+			hw_battery.history_tail->next = history;
+			if(hw_battery.history_tail->capacity < capacity) hw_battery.charge_point = history; // set a charging point
+		}
+		hw_battery.history_tail = history;
+	}
+}
+static void new_charger( double timestamp, unsigned state ){
+	current_time = base_time + timestamp;
+	hw_new_event("charger", &hw_battery.charger_history_head, &hw_battery.charger_history_tail, state);
+}
+static void new_screen( double timestamp, unsigned state ){
+	current_time = base_time + timestamp;
+	hw_new_event("screen", &hw_screen.history_head, &hw_screen.history_tail, state);
+}
+#endif
+
 static void bme_init( ){
 	battery_reporting_design = 0;
 	hw_battery.initialize = 1;
@@ -750,6 +793,32 @@ static void bme_init( ){
 	hw_battery.hours1 = 0;
 	hw_battery.hours24 = 2;
 	hw_battery.history_head = hw_battery.history_tail = hw_battery.charge_point = NULL;
+	hw_battery.charger_history_head = hw_battery.charger_history_tail = NULL;
+
+	#ifdef TESTLOG
+	// inject fake battery capacity and events for testing the graph
+	double old_time = current_time;
+	base_time = current_time - 7*86400;
+
+	new_battcap(0 + 120, 100.0);	// this event should be removed after 2 minutes, what happens?
+	new_battcap(1*86400, 85.0);
+	new_battcap(2*86400, 66.0);
+	new_battcap(3*86400, 50.0);
+	new_battcap(5*86400, 10.0);
+	new_battcap(5*86400 + 5000, 100.0); // battery charged to full
+
+	new_charger(5*86400, 1);
+	new_charger(5*86400 + 7200, 0); // 2 hour charging event, 5 days in
+
+	new_screen(1*86400, 1); new_screen(1*86400 +  60, 0); // 1 minutes on
+	new_screen(2*86400, 1); new_screen(2*86400 + 120, 0); // 2 minutes on
+	new_screen(3*86400, 1); new_screen(3*86400 + 180, 0); // 3 minutes on
+	new_screen(4*86400, 1); new_screen(4*86400 + 240, 0); // 4 minutes on
+	new_screen(5*86400, 1); new_screen(5*86400 + 300, 0); // 5 minutes on
+	new_screen(6*86400, 1); new_screen(6*86400 + 360, 0); // 6 minutes on
+
+	current_time = old_time;
+	#endif
 
 	#ifdef ARCH_armel
 	last_battery_history_refresh = 0.0;
