@@ -43,6 +43,7 @@ typedef struct s_hw_battery {
 	unsigned hours24;
 	s_battery_history *history_head, *history_tail;
 	s_battery_history *charge_point;
+	s_event_history *charger_history_head, *charger_history_tail;
 } s_hw_battery;
 
 typedef struct s_hw_governor {
@@ -172,6 +173,7 @@ void hw_set_brightness( unsigned level, unsigned update );
 #else
  #define debug_tklock_state(section) {}/* do nothing */
 #endif
+void hw_restore_cp_screen_settings( );
 void mce_wake_screen( );
 void mce_dim_screen( unsigned expect );
 void mce_blank_screen( );
