@@ -69,6 +69,9 @@
 // for RBV keys
 #include "widget_volume.h"
 
+// button editor needs to keep rotation buttons on primary page
+#include "button_rotate.h"
+
 ////////////////////////////////////////////////////////////////////////// GLOBALS
 
 // device model
@@ -98,7 +101,7 @@ unsigned button_autorepeat;
 s_timer motion_timer;
 unsigned (*motion_callback)( );
 
-unsigned primary_widgets, widget_edit_mode;
+unsigned primary_widgets, widget_edit_mode, button_edit_mode;
 s_selected_cell selected_cell;
 unsigned brightness_widget_page, volume_widget_page, battery_widget_page, wifi_widget_page, bluetooth_widget_page, usb_widget_page;
 unsigned flightmode_button_page, keyrepeat_button_page, screenstayslit_button_page, screenautolock_button_page;
@@ -191,13 +194,72 @@ unsigned file_exists( const char *file ){
 ////////////////////////////////////////////////////////////////////////// BUTTON CELLS
 
 static void _draw_button( unsigned force, int x, int y, s_button *button ){
-	if(button == NULL) return;
-	button->draw(force, x, y);
+	if(button_edit_mode){
+		if(force){
+			if(button){
+				XColor *color;
+				if(selected_cell.button == button){
+					x_set_color(selection_color);
+					x_fill_rectangle(x,y, 80,80);
+					color = bg_color;
+				} else color = fg1_color;
+				draw_text((char *)button->name, 12, color, x+39, y+45, ALIGN_CENTER, ALIGN_BASELINE, 0);
+			} else {
+				x_set_color(line_color);
+				x_fill_ellipse(x+34,y+34, 11,11);
+			}
+		}
+	} else if(button)
+		button->draw(force, x, y);
+}
+
+static void _move_button( s_button *button, unsigned cell ){
+	// hw_refresh() needs the rotation buttons to stay on primary page so it can call check_orientation()
+	if((selected_cell.button == &button_rotate1 || selected_cell.button == &button_rotate2 || selected_cell.button == &button_rotate3) && cell >= 10)
+		return;
+
+	highlight_selected_area(widget_x, widget_y, 80, 80);
+
+	// swap button with another button or an empty cell
+	button_cells[selected_cell.cell] = button;
+	button_cells[cell] = selected_cell.button;
+
+	// save configuration
+	if(button){
+		button->cell = selected_cell.cell;
+		conf_set_int(button->conf, selected_cell.cell);
+	}
+	selected_cell.button->cell = cell;
+	conf_set_int(selected_cell.button->conf, cell);
+
+	// clear selected cell
+	selected_cell.button = NULL;
+	draw_window(1);
 }
 
 static void _click_button( s_button *button, unsigned cell ){
-	if(button == NULL) return;
-	button->click();
+	if(button_edit_mode && selected_cell.button && click.type == CLICK_SHORT){
+
+		// clear selection or move selected button
+		if(button == selected_cell.button){
+			highlight_long_press(widget_x, widget_y, 80,80);
+			selected_cell.button = NULL;
+			reset_long_press(); // highlight removed when window is redrawn
+			draw_window(1);
+		} else
+			_move_button(button, cell);
+
+	} else if(button_edit_mode && button){
+
+		if(click.type == CLICK_SHORT){
+			// select button
+			selected_cell.button = button;
+			selected_cell.cell = cell;
+			_draw_button(1, widget_x, widget_y, button);
+		}
+
+	} else if(button)
+		button->click();
 }
 
 ////////////////////////////////////////////////////////////////////////// WIDGET CELLS
@@ -252,7 +314,7 @@ static void _draw_widget( unsigned force, int x, int y, s_widget_cell *widget_ce
 	}
 }
 
-static unsigned _move_widget( s_widget_cell *widget_cell, unsigned cell, unsigned subcell ){
+static void _move_widget( s_widget_cell *widget_cell, unsigned cell, unsigned subcell ){
 	e_widget_size src_size = selected_cell.widget_cell->size, dst_size = widget_cell->size;
 
 	if(src_size == FULL_WIDGET)
@@ -320,15 +382,12 @@ static unsigned _move_widget( s_widget_cell *widget_cell, unsigned cell, unsigne
 	// clear selected cell
 	selected_cell.widget_cell = NULL;
 	draw_window(1);
-
-// TODO: window isn't refreshing immediately and a usleep doesn't help
-
-	return 1;
 }
 
 static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 	if(widget_edit_mode && selected_cell.widget_cell && click.type == CLICK_SHORT){
 
+		// clear selection or move selected widget
 		unsigned subcell = (click.x >= 200 ? 1 : 0);
 		if(widget_cell == selected_cell.widget_cell && (widget_cell->size == FULL_WIDGET || (widget_cell->size == HALF_WIDGET && selected_cell.subcell == subcell))){
 			if(widget_cell->size == FULL_WIDGET)
@@ -345,6 +404,7 @@ static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 
 		if(widget_edit_mode){
 			if(click.type == CLICK_SHORT){
+				// select widget
 				selected_cell.widget_cell = widget_cell;
 				selected_cell.cell = cell;
 				selected_cell.subcell = 0;
@@ -359,6 +419,7 @@ static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 			if(widget_cell->right){
 				if(widget_edit_mode){
 					if(click.type == CLICK_SHORT){
+						// select widget
 						selected_cell.widget_cell = widget_cell;
 						selected_cell.cell = cell;
 						selected_cell.subcell = 1;
@@ -373,6 +434,7 @@ static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 		} else if(widget_cell->left){
 			if(widget_edit_mode){
 				if(click.type == CLICK_SHORT){
+					// select widget
 					selected_cell.widget_cell = widget_cell;
 					selected_cell.cell = cell;
 					selected_cell.subcell = 0;
@@ -501,12 +563,25 @@ static void draw_button_guide_lines( unsigned rows ){
 */
 
 static void _draw_selection_button( int x, int y ){
-	if(selected_cell.widget_cell && ((primary_widgets && selected_cell.cell > 7) || (!primary_widgets && selected_cell.cell < 8))){
-		s_widget *widget = (selected_cell.subcell == 0 ? selected_cell.widget_cell->left : selected_cell.widget_cell->right);
-		x_set_color(selection_color);
-		x_fill_rectangle(x,y, 80,80);
-		draw_text((char *)widget->name, 12, bg_color, x+40,y+40, ALIGN_CENTER, ALIGN_MIDDLE, 76);
-		draw_text((widget->size == FULL_WIDGET ? "FULL" : "HALF"), 8, fg1_color, x+75,y+5, ALIGN_RIGHT, ALIGN_TOP, 0);
+	if(widget_edit_mode){
+		// widgets
+		if(selected_cell.widget_cell && ((primary_widgets && selected_cell.cell > 7) || (!primary_widgets && selected_cell.cell < 8))){
+			s_widget *widget = (selected_cell.subcell == 0 ? selected_cell.widget_cell->left : selected_cell.widget_cell->right);
+			x_set_color(selection_color);
+			x_fill_rectangle(x,y, 80,80);
+			draw_text((char *)widget->name, 12, bg_color, x+40,y+40, ALIGN_CENTER, ALIGN_MIDDLE, 76);
+			draw_text((widget->size == FULL_WIDGET ? "FULL" : "HALF"), 8, fg1_color, x+75,y+5, ALIGN_RIGHT, ALIGN_TOP, 0);
+		}
+	} else {
+		// buttons
+		if(selected_cell.button && ((primary_widgets && selected_cell.cell > 9) || (!primary_widgets && selected_cell.cell < 10))){
+			x_set_color(selection_color);
+			x_fill_rectangle(x,y, 80,80);
+			draw_text((char *)selected_cell.button->name, 12, bg_color, x+40,y+40, ALIGN_CENTER, ALIGN_MIDDLE, 76);
+			// hw_refresh() needs the rotation buttons to stay on primary page so it can call check_orientation()
+			if((selected_cell.button == &button_rotate1 || selected_cell.button == &button_rotate2 || selected_cell.button == &button_rotate3) && !primary_widgets)
+				draw_text("CAN'T MOVE", 8, fg1_color, x+75,y+5, ALIGN_RIGHT, ALIGN_TOP, 0);
+		}
 	}
 }
 
@@ -525,7 +600,7 @@ static void draw_editmode_buttons( unsigned landscape ){
 		_draw_exit_button(720,0);		// 10
 	} else { // PORTRAIT
 		_draw_selection_button(400,0);	//  1
-		_draw_page_button(400,400);		// 5.5
+		_draw_page_button(440,360);		// 5.5
 		_draw_exit_button(400,720);		// 10
 	}
 }
@@ -585,24 +660,31 @@ void draw_window( unsigned force ){
 			// half widgets are 199x99 with a clickable line on the right side of each (invisible for widgets in right subcell in right column)
 
 			if(force){
-				// separators
 				x_set_color(line_color);
-				x_draw_line(399, 81, 399, 480);
-				int y;
-				for(y = 80; y < 479; y += 100)
-					x_draw_line(0, y, 800, y);
+				if(button_edit_mode){
+					// separator between buttons and widgets
+					x_draw_line(0, 80, 799, 80);
+					// separator below button editor
+					x_draw_line(0, 161, 799, 161);
+				} else {
+					// separators (not in button editor)
+					x_draw_line(399, 81, 399, 480);
+					int y;
+					for(y = 80; y < 479; y += 100)
+						x_draw_line(0, y, 799, y);
+				}
 			}
 
 			if(primary_widgets){
 				// PRIMARY WIDGETS (LANDSCAPE)
 
 				// buttons
-				if(widget_edit_mode){
+				if(widget_edit_mode || button_edit_mode){
 					if(force) draw_editmode_buttons(1);
 				} else {
 					int x, i;
 					for(x = 0, i = 0; i < 10; x += 80, i++)
-						_draw_button(force, x, 0, landscape_bcells[i]);
+						_draw_button(force, x, 0, button_cells[i]);
 
 /*
 // button guide lines
@@ -618,36 +700,50 @@ x_reset_style();
 					draw_self_rss(force, 400, 0, 1);
 				}
 
-				// widgets
-				_draw_widget(force,   0,  81, &landscape_cells[0]);
-				_draw_widget(force,   0, 181, &landscape_cells[1]);
-				_draw_widget(force,   0, 281, &landscape_cells[2]);
-				_draw_widget(force,   0, 381, &landscape_cells[3]);
-				_draw_widget(force, 400,  81, &landscape_cells[4]);
-				_draw_widget(force, 400, 181, &landscape_cells[5]);
-				_draw_widget(force, 400, 281, &landscape_cells[6]);
-				_draw_widget(force, 400, 381, &landscape_cells[7]);
+				if(button_edit_mode){
+					// draw button editor below the button bar
+					int x, i;
+					for(x = 0, i = 0; i < 10; x += 80, i++)
+						_draw_button(force, x, 81, button_cells[i]);
+				} else {
+					// widgets
+					_draw_widget(force,   0,  81, &landscape_cells[0]);
+					_draw_widget(force,   0, 181, &landscape_cells[1]);
+					_draw_widget(force,   0, 281, &landscape_cells[2]);
+					_draw_widget(force,   0, 381, &landscape_cells[3]);
+					_draw_widget(force, 400,  81, &landscape_cells[4]);
+					_draw_widget(force, 400, 181, &landscape_cells[5]);
+					_draw_widget(force, 400, 281, &landscape_cells[6]);
+					_draw_widget(force, 400, 381, &landscape_cells[7]);
+				}
 			} else {
 				// SECONDARY WIDGETS (LANDSCAPE)
 
 				// buttons
-				if(widget_edit_mode){
+				if(widget_edit_mode || button_edit_mode){
 					if(force) draw_editmode_buttons(1);
 				} else {
 					int x, i;
 					for(x = 0, i = 10; i < 20; x += 80, i++)
-						_draw_button(force, x, 0, landscape_bcells[i]);
+						_draw_button(force, x, 0, button_cells[i]);
 				}
 
-				// widgets
-				_draw_widget(force,   0,  81, &landscape_cells[8]);
-				_draw_widget(force,   0, 181, &landscape_cells[9]);
-				_draw_widget(force,   0, 281, &landscape_cells[10]);
-				_draw_widget(force,   0, 381, &landscape_cells[11]);
-				_draw_widget(force, 400,  81, &landscape_cells[12]);
-				_draw_widget(force, 400, 181, &landscape_cells[13]);
-				_draw_widget(force, 400, 281, &landscape_cells[14]);
-				_draw_widget(force, 400, 381, &landscape_cells[15]);
+				if(button_edit_mode){
+					// draw button editor below the button bar
+					int x, i;
+					for(x = 0, i = 10; i < 20; x += 80, i++)
+						_draw_button(force, x, 81, button_cells[i]);
+				} else {
+					// widgets
+					_draw_widget(force,   0,  81, &landscape_cells[8]);
+					_draw_widget(force,   0, 181, &landscape_cells[9]);
+					_draw_widget(force,   0, 281, &landscape_cells[10]);
+					_draw_widget(force,   0, 381, &landscape_cells[11]);
+					_draw_widget(force, 400,  81, &landscape_cells[12]);
+					_draw_widget(force, 400, 181, &landscape_cells[13]);
+					_draw_widget(force, 400, 281, &landscape_cells[14]);
+					_draw_widget(force, 400, 381, &landscape_cells[15]);
+				}
 			}
 
 		} else {
@@ -663,12 +759,18 @@ x_reset_style();
 			// half widgets are 199x99 with a clickable line on the right side of each
 
 			if(force){
-				// separators
 				x_set_color(line_color);
-				x_draw_line(399, 0, 399, 800);
-				int y;
-				for(y = 100; y < 799; y += 100)
-					x_draw_line(0, y, 399, y);
+				// separator between buttons and widgets
+				x_draw_line(399, 0, 399, 799);
+				if(button_edit_mode){
+					// separator below button editor
+					x_draw_line(318, 0, 318, 799);
+				} else {
+					// widget separators (not in button editor)
+					int y;
+					for(y = 100; y < 799; y += 100)
+						x_draw_line(0, y, 399, y);
+				}
 			}
 
 			if(primary_widgets){
@@ -676,33 +778,45 @@ x_reset_style();
 				int y, i;
 
 				// buttons
-				if(widget_edit_mode){
+				if(widget_edit_mode || button_edit_mode){
 					if(force) draw_editmode_buttons(0);
 				} else {
 					for(y = 0, i = 0; i < 10; y += 80, i++)
-						_draw_button(force, 400, y, portrait_bcells[i]);
+						_draw_button(force, 400, y, button_cells[i]);
 
 					draw_self_rss(force, 479, 400, 0);
 				}
 
-				// widgets
-				for(y = 1, i = 0; i < 8; y += 100, i++)
-					_draw_widget(force, 0, y, &portrait_cells[i]);
+				if(button_edit_mode){
+					// draw button editor to the left of the button bar
+					for(y = 0, i = 0; i < 10; y += 80, i++)
+						_draw_button(force, 319, y, button_cells[i]);
+				} else {
+					// widgets
+					for(y = 1, i = 0; i < 8; y += 100, i++)
+						_draw_widget(force, 0, y, &portrait_cells[i]);
+				}
 			} else {
 				// SECONDARY WIDGETS (PORTRAIT)
 				int y, i;
 
 				// buttons
-				if(widget_edit_mode){
+				if(widget_edit_mode || button_edit_mode){
 					if(force) draw_editmode_buttons(0);
 				} else {
 					for(y = 0, i = 10; i < 20; y += 80, i++)
-						_draw_button(force, 400, y, portrait_bcells[i]);
+						_draw_button(force, 400, y, button_cells[i]);
 				}
 
-				// widgets
-				for(y = 1, i = 8; i < 16; y += 100, i++)
-					_draw_widget(force, 0, y, &portrait_cells[i]);
+				if(button_edit_mode){
+					// draw button editor to the left of the button bar
+					for(y = 0, i = 10; i < 20; y += 80, i++)
+						_draw_button(force, 319, y, button_cells[i]);
+				} else {
+					// widgets
+					for(y = 1, i = 8; i < 16; y += 100, i++)
+						_draw_widget(force, 0, y, &portrait_cells[i]);
+				}
 			}
 		}
 
@@ -717,27 +831,39 @@ x_reset_style();
 ////////////////////////////////////////////////////////////////////////// CLICKS
 
 static void click_button( unsigned button ){
-	if(widget_edit_mode){
+	if(widget_edit_mode || button_edit_mode){
 		switch(button){
-		case 0: // selected widget button
+		case 0: // selected widget/button button
 
-			if(click.type != CLICK_SHORT || selected_cell.widget_cell == NULL || !widget_edit_mode) return;
+			if(widget_edit_mode){
+				if(click.type != CLICK_SHORT || selected_cell.widget_cell == NULL) return;
 
-			highlight_long_press(widget_x, widget_y, 80,80);
-			selected_cell.widget_cell = NULL;
+				highlight_long_press(widget_x, widget_y, 80,80);
+				selected_cell.widget_cell = NULL;
+			} else {
+				if(click.type != CLICK_SHORT || selected_cell.button == NULL) return;
+
+				highlight_long_press(widget_x, widget_y, 80,80);
+				selected_cell.button = NULL;
+			}
 			reset_long_press();
 
 			// redraw window
 			draw_window(1);
 			break;
 
-		case 9: // exit widget edit mode
+		case 9: // exit edit mode
 
-			if(click.type != CLICK_SHORT || !widget_edit_mode) return;
+			if(click.type != CLICK_SHORT) return;
 
 			highlight_selected_area(widget_x, widget_y, 80,80);
-			widget_edit_mode = 0;
-			selected_cell.widget_cell = NULL;
+			if(widget_edit_mode){
+				widget_edit_mode = 0;
+				selected_cell.widget_cell = NULL;
+			} else {
+				button_edit_mode = 0;
+				selected_cell.button = NULL;
+			}
 
 			// redraw window
 			draw_window(1);
@@ -746,10 +872,7 @@ static void click_button( unsigned button ){
 		}
 	} else {
 		button += (primary_widgets ? 0 : 10);
-		if(window.width > window.height)
-			_click_button(landscape_bcells[button], button); // LANDSCAPE
-		else
-			_click_button(portrait_bcells[button], button); // PORTRAIT
+		if(button_cells[button]) button_cells[button]->click(); // LANDSCAPE or PORTRAIT
 	}
 }
 
@@ -829,9 +952,22 @@ static void screen_event( ){
 					// hide the window with a vertical swipe from button bar to widgets (10 pixels into widgets, +-100 pixel horizontal deviation)
 					window_unmap();
 				} else {
+					uint button = click.start_x / 80;
 					widget_x = (click.start_x / 80)*80;
 					widget_y = 0;
-					click_button(click.start_x / 80);
+					click.x = click.start_x - button*80;
+					click.y = click.start_y;
+					click_button(button);
+				}
+			} else if(button_edit_mode){
+				if(click.start_y <= 160){
+					uint button = click.start_x / 80;
+					widget_x = (click.start_x / 80)*80;
+					widget_y = 81;
+					click.x = click.start_x - button*80;
+					click.y = click.start_y - 81;
+					button += (primary_widgets ? 0 : 10);
+					_click_button(button_cells[button], button);
 				}
 			} else if(click.start_x < 400){
 				// left widgets
@@ -868,9 +1004,22 @@ static void screen_event( ){
 					// hide the window with a horizontal swipe from button bar to widgets (10 pixels into widgets, +-100 pixel vertical deviation)
 					window_unmap();
 				} else {
+					uint button = click.start_y / 80;
 					widget_x = 400;
 					widget_y = (click.start_y / 80)*80;
-					click_button(click.start_y / 80);
+					click.x = click.start_x - 400;
+					click.y = click.start_y - button*80;
+					click_button(button);
+				}
+			} else if(button_edit_mode){
+				if(click.start_x >= 319){
+					uint button = click.start_y / 80;
+					widget_x = 319;
+					widget_y = (click.start_y / 80)*80;
+					click.x = click.start_x - 319;
+					click.y = click.start_y - button*80;
+					button += (primary_widgets ? 0 : 10);
+					_click_button(button_cells[button], button);
 				}
 			} else {
 				// widgets
@@ -890,7 +1039,7 @@ static void screen_event( ){
 
 static int button_up( unsigned button_group ){
 	if(button_group == cfg_buttons_rotate){
-		if(widget_edit_mode) return 0; // rotation can't be changed in widget edit mode
+		if(widget_edit_mode || button_edit_mode) return 0; // rotation can't be changed in widget/button edit mode
 		if(keypress.type != KEY_SHORT) return 1;
 
 		if(window.supports_rotation){
@@ -903,7 +1052,7 @@ static int button_up( unsigned button_group ){
 		}
 		return 1;
 	} else if(button_group == cfg_buttons_brightness){
-		if(current_dialog_draw != NULL || widget_edit_mode || brightness_widget_page != primary_widgets)
+		if(current_dialog_draw != NULL || widget_edit_mode || button_edit_mode || brightness_widget_page != primary_widgets)
 			return 0; // brightness can only be changed when slider is visible
 		if(keypress.type != KEY_SHORT) return 1;
 
@@ -913,7 +1062,7 @@ static int button_up( unsigned button_group ){
 		}
 		return 1;
 	} else if(button_group == cfg_buttons_volume){
-		if(current_dialog_draw != NULL || widget_edit_mode || volume_widget_page != primary_widgets)
+		if(current_dialog_draw != NULL || widget_edit_mode || button_edit_mode || volume_widget_page != primary_widgets)
 			return 0; // volume can only be changed when slider is visible
 		if(keypress.type != KEY_SHORT) return 1;
 
@@ -930,7 +1079,7 @@ static int button_up( unsigned button_group ){
 
 static int button_down( unsigned button_group ){
 	if(button_group == cfg_buttons_rotate){
-		if(widget_edit_mode) return 0; // rotation can't be changed in widget edit mode
+		if(widget_edit_mode || button_edit_mode) return 0; // rotation can't be changed in widget/button edit mode
 		if(keypress.type != KEY_SHORT) return 1;
 
 		if(window.supports_rotation){
@@ -943,7 +1092,7 @@ static int button_down( unsigned button_group ){
 		}
 		return 1;
 	} else if(button_group == cfg_buttons_brightness){
-		if(current_dialog_draw != NULL || widget_edit_mode || brightness_widget_page != primary_widgets)
+		if(current_dialog_draw != NULL || widget_edit_mode || button_edit_mode || brightness_widget_page != primary_widgets)
 			return 0; // brightness can only be changed when slider is visible
 		if(keypress.type != KEY_SHORT) return 1;
 
@@ -954,7 +1103,7 @@ static int button_down( unsigned button_group ){
 		}
 		return 1;
 	} else if(button_group == cfg_buttons_volume){
-		if(current_dialog_draw != NULL || widget_edit_mode || brightness_widget_page != primary_widgets)
+		if(current_dialog_draw != NULL || widget_edit_mode || button_edit_mode || brightness_widget_page != primary_widgets)
 			return 0; // volume can only be changed when slider is visible
 		if(keypress.type != KEY_SHORT) return 1;
 
@@ -1054,11 +1203,13 @@ static void main_keypress_handler( ){
 	switch(keypress.keycode){
 	case KEYCODE_ESCAPE:
 		if(keypress.type == KEY_SHORT){
-			if(widget_edit_mode){
-				// exit widget edit mode
+			if(widget_edit_mode || button_edit_mode){
+				// exit edit mode
 				highlight_selected_area(window.width-80, (window.width > window.height ? 0 : window.height-80), 80,80); // highlight removed when window is redrawn
 				widget_edit_mode = 0;
 				selected_cell.widget_cell = NULL;
+				button_edit_mode = 0;
+				selected_cell.button = NULL;
 				draw_window(1); // refresh, force to clear highlight
 			} else
 				window_unmap();
@@ -1099,8 +1250,9 @@ static void main_keypress_handler( ){
 void main_reset( ){
 	// return to primary widget page
 	primary_widgets = 1;
-	// exit widget edit mode
+	// exit edit mode
 	widget_edit_mode = 0;
+	button_edit_mode = 0;
 }
 
 static int clean_up_stage, dbus_fd;
@@ -1320,6 +1472,7 @@ if(runlevel == 2){
 
 	primary_widgets = 1;
 	widget_edit_mode = 0;
+	button_edit_mode = 0;
 	if(cfg_start_visible) window_map();
 
 	#ifdef ARCH_armel
@@ -1646,7 +1799,7 @@ if(runlevel == 2){
 				case _WAKEUP_ROTATE_LEFT_:
 
 					// rotate screen left
-					if(!widget_edit_mode){ // rotation can't be changed in widget edit mode
+					if(!widget_edit_mode && !button_edit_mode){ // rotation can't be changed in widget/button edit mode
 						if(window.supports_rotation){
 							switch(window.orientation){
 							case O_LANDSCAPE: rotate_screen(O_PORTRAIT_INV, window.is_mapped); break;
@@ -1661,7 +1814,7 @@ if(runlevel == 2){
 				case _WAKEUP_ROTATE_RIGHT_:
 
 					// rotate screen right
-					if(!widget_edit_mode){ // rotation can't be changed in widget edit mode
+					if(!widget_edit_mode && !button_edit_mode){ // rotation can't be changed in widget/button edit mode
 						if(window.supports_rotation){
 							switch(window.orientation){
 							case O_LANDSCAPE: rotate_screen(O_PORTRAIT, window.is_mapped); break;
@@ -1812,7 +1965,7 @@ if(runlevel == 2){
 				secureShowKeypad();
 
 			// MAIN LOOP
-			if(hw_screen.visible && window.is_mapped && current_dialog_draw == NULL && !widget_edit_mode){
+			if(hw_screen.visible && window.is_mapped && current_dialog_draw == NULL && !widget_edit_mode && !button_edit_mode){
 				if(is_timer_ready(&refresh_timer)){
 					debug_write("    main refresh");
 
