@@ -68,9 +68,10 @@ extern unsigned button_autorepeat;
 extern s_timer motion_timer;
 extern unsigned (*motion_callback)( );
 
-extern unsigned primary_widgets, widget_edit_mode;
+extern unsigned primary_widgets, widget_edit_mode, button_edit_mode;
 typedef struct s_selected_cell {
 	struct s_widget_cell *widget_cell;
+	struct s_button *button;
 	unsigned cell;
 	unsigned subcell;
 } s_selected_cell;
