@@ -12,7 +12,7 @@ static unsigned alarm_duration, min_volume, max_volume;
 static void update_volume_step( ){
 	char buffer[200];
 	snprintf(buffer, sizeof(buffer),
-		"Volume is increased by step value every 10 seconds upto maximum level."
+		"Volume is increased from min/100 to max/100 by step value every 10 seconds upto maximum level."
 		" The step value must be greater than or equal to %u in order for alarm to reach maximum level.",
 		100*(max_volume - min_volume)/(alarm_duration-10)
 	);
@@ -68,7 +68,7 @@ void alarm_click_callback( GtkWidget *widget, gpointer data ){
 	min_volume_widget = new_uint_value(conf_alarm_volume_min, "minimum volume level", 10, 100, change_min_volume);
 	max_volume_widget = new_uint_value(conf_alarm_volume_max, "maximum volume level", 10, 100, change_max_volume);
 
-	new_uint_value(conf_alarm_volume_step, "volume step in milliseconds", 0, 1000, NULL);
+	new_uint_value(conf_alarm_volume_step, "volume step / 1000", 0, 1000, NULL);
 	volume_step_label = new_message("");
 	update_volume_step();
 
