@@ -80,7 +80,6 @@ const char *conf_buttons_volume_step = "/apps/asui/buttons_volume_step";
 // button modes
 const char *conf_double_tap = "/apps/asui/double_tap";
 const char *conf_lock_and_close = "/apps/asui/lock_and_close";
-const char *conf_n800_lock_mode = "/apps/asui/n800_lock_mode";
 const char *conf_rotate_and_close = "/apps/asui/rotate_and_close";
 const char *conf_buttons_dpad_short = "/apps/asui/buttons_dpad_short";
 const char *conf_buttons_dpad_long = "/apps/asui/buttons_dpad_long";
@@ -91,6 +90,7 @@ const char *conf_buttons_lock2_long = "/apps/asui/buttons_lock2_long";
 const char *conf_secure_action = "/apps/asui/secure_action";
 const char *conf_secure_power_action = "/apps/asui/secure_power_action";
 const char *conf_secure_button = "/apps/asui/secure_button";
+const char *conf_power_action = "/apps/asui/power_action";
 const char *conf_power_unlock_key = "/apps/asui/power_unlock_key";
 // user interface
 const char *conf_tkactive_notifications = "/apps/asui/tkactive_notifications";
