@@ -9,6 +9,11 @@
 void ui_click_callback( GtkWidget *widget, gpointer data ){
 	new_section_vbox("User Interface"); // add setting widgets to section_content_box
 
+	new_message("\"Touch screen and keys active\" notification can be displayed when the screen is turned on but wasn't locked.");
+	new_checkbox(conf_tkactive_notifications, "show this notification", NULL);
+
+	new_separator();
+
 	new_checkbox(conf_service_size_unit, "show \"MB\" after service size", NULL);
 
 	new_separator();
