@@ -1,41 +1,14 @@
 #!/bin/sh
 
-#QZX="linode"
-QZX="qzx"
-
 cd /opt/scratchbox/users/test/home/test/advanced-systemui/
 
 function echo_msg(){
 	echo -e "\033[36;2m$1\033[0m"
 }
 
-function rsync_command() {
-	# 2>&1
-	EXCLUDES="" ; [ -f ".excludes" ] && EXCLUDES="--exclude-from=.excludes --exclude=.excludes"
-	rsync -lrtvz $EXCLUDES $* 2>&1 \
-		|grep -v "^building file list" |grep -v "^receiving file list" |grep -v "^sent " |grep -v "^total size is" |grep -v "^$" |grep -v "^[.]/$" \
-		|grep -v "^wrote " |grep -v "sending incremental file list" |grep -v "is not a tty"
-#		|awk '{if(n==2) printf("  %s\n", $0); if($0=="-----------------------------------------------------------------------------") n+=1}'
-}
-function rsync_check() {
-	# 2>&1
-	EXCLUDES="" ; [ -f ".excludes" ] && EXCLUDES="--exclude-from=.excludes --exclude=.excludes"
-	rsync --dry-run -lrtvz $EXCLUDES $* 2>&1 \
-		|grep -v "^building file list" |grep -v "^receiving file list" |grep -v "^sent " |grep -v "^total size is" |grep -v "^$" |grep -v "^[.]/$" \
-		|grep -v "^wrote " |grep -v "sending incremental file list" |grep -v "is not a tty"
-#		|awk '{if(n==2) printf("  %s\n", $0); if($0=="-----------------------------------------------------------------------------") n+=1}'
-}
-
-#if [ "$1" = "upload" ]; then
-#	echo_msg "uploading files to QZx..."
-#	rsync_command ./ $QZX:www/tmp/advanced-systemui/
-#elif [ "$1" = "check" ]; then
-#	echo_msg "comparing files with QZx..."
-#	rsync_check ./ $QZX:www/tmp/advanced-systemui/
-#el
 if [ "$1" = "tar" ]; then
 	cd ..
-	tar -X advanced-systemui/.excludes-tar -jcvf advanced-systemui.tar.bz2 advanced-systemui/
+	tar -X advanced-systemui/.excludes -jcvf advanced-systemui.tar.bz2 advanced-systemui/
 	echo_msg "Moving source code to web directory for upload..."
 	install -o asd -g apache -m 640 advanced-systemui.tar.bz2 /home/http/html/asui/_download/
 elif [ "$1" = "deb" ]; then
@@ -45,11 +18,10 @@ elif [ "$1" = "deb" ]; then
 	echo_msg "cd ../repo ; dpkg-scanpackages dists/diablo/free/binary-armel /dev/null | gzip -9c > dists/diablo/free/binary-armel/Packages.gz ; cd ../advanced-systemui"
 elif [ "$1" = "repo" ]; then
 	cd ..
-	echo_msg "Moving deb file to repo..."
+	echo_msg "Moving deb file to local repo..."
 	install -o asd -g apache -m 640 repo/dists/diablo/free/binary-armel/Packages.gz /home/http/html/asui/repo/dists/diablo/free/binary-armel/
 	install -o asd -g apache -m 640 repo/dists/diablo/free/binary-armel/advanced-systemui/*.deb /home/http/html/asui/repo/dists/diablo/free/binary-armel/advanced-systemui
 	rm -f repo/dists/diablo/free/binary-armel/advanced-systemui/*.deb
-	echo_msg "Now go upload the main website to sync tarball to QZx"
 elif [ "$1" = "web" ]; then
 	echo_msg "Moving asui script to web directory for upload..."
 	install -o asd -g apache -m 640 asui.sh /home/http/html/asui/_download/
@@ -65,6 +37,10 @@ elif [ "$1" = "web" ]; then
 		echo_msg "Moving asui-settings test binary to web directory for upload..."
 		install -o asd -g apache -m 640 settings/advanced-systemui-settings /home/http/html/asui/_download/asui-settings-test
 	fi
+	if [ -f "statusbar/libasui-battery.so" ]; then
+		echo_msg "Moving statusbar test applet to web directory for upload..."
+		install -o asd -g apache -m 640 statusbar/libasui-battery.so /home/http/html/asui/_download/asui-statusbar-test
+	fi
 elif [ "$1" = "n810" ]; then
 	echo_msg "Transfering asui script to n810..."
 	scp asui.sh n810:/usr/bin/asui
@@ -83,23 +59,25 @@ elif [ "$1" = "n810" ]; then
 		scp settings/advanced-systemui-settings n810:/root/.asui-settings-test
 		ssh n810 chmod 755 /root/.asui-settings-test
 	fi
-elif [ "$1" = "sb" ]; then
-	echo_msg "Transfering statusbar applets to n810..."
-	scp statusbar/asui-*.desktop n810:/usr/share/applications/hildon-status-bar/
-	scp statusbar/libasui-*.so n810:/usr/lib/hildon-desktop/
-	ssh n810 chmod 644 /usr/lib/hildon-desktop/libasui-*.so /usr/share/applications/hildon-status-bar/asui-*.desktop
-elif [ "$1" = "rmsb" ]; then
-	echo_msg "Removing statusbar applets from n810..."
-	ssh n810 rm /usr/lib/hildon-desktop/libasui-*.so /usr/share/applications/hildon-status-bar/asui-*.desktop
+	if [ -f "statusbar/libasui-battery.so" ]; then
+		echo_msg "Transfering statusbar test applet to n810..."
+		scp statusbar/libasui-battery.so n810:/usr/lib/hildon-desktop/
+		scp statusbar/asui-battery.desktop n810:/usr/share/applications/hildon-status-bar/
+		ssh n810 chmod 644 /usr/lib/hildon-desktop/libasui-battery.so /usr/share/applications/hildon-status-bar/asui-battery.desktop
+	fi
 elif [ "$1" = "icons" ]; then
-	echo_msg "Transfering statusbar icons to n810..."
+	echo_msg "Transfering desktop and statusbar icons to n810..."
+	scp asui_icon.png asui_settings_icon.png n810:/usr/share/icons/hicolor/64x64/hildon/
 	scp statusbar/icons/* n810:/usr/share/icons/hicolor/40x40/hildon/
 	ssh n810 gtk-update-icon-cache -f /usr/share/icons/hicolor
-elif [ "$1" = "getsb" ]; then
-	echo_msg "Downloading statusbar-applet-test from n810..."
-	scp n810:/root/statusbar-applet-test.tar.gz /home/http/html/asui/_download/
-	chmod 640 /home/http/html/asui/_download/statusbar-applet-test.tar.gz
-	chown asd.apache /home/http/html/asui/_download/statusbar-applet-test.tar.gz
+elif [ "$1" = "release" ]; then
+	if [ "$2" != "" ]; then
+		echo_msg "Transfering $2 package files to extras-devel repository..."
+		scp ../advanced-systemui_${2}.tar.gz ../advanced-systemui_${2}_armel.changes ../advanced-systemui_${2}.dsc \
+			brand@drop.maemo.org:/var/www/extras-devel/incoming-builder/diablo/
+	else
+		echo "Syntax: $0 release <version>"
+	fi
 else
-	echo "Syntax: $0 <upload/check/tar/deb/repo/web/n810/sb/rmsb/icons/getsb>"
+	echo "Syntax: $0 <tar/deb/repo/web/n810/icons/release>"
 fi
