@@ -1,5 +1,5 @@
 //	Advanced System UI
-//	Copyright (c) 2010 Brand Huntsman <brand.huntsman@gmail.com>
+//	Copyright (c) 2010-2011 Brand Huntsman <brand.huntsman@gmail.com>
 
 #include <unistd.h>
 
@@ -18,6 +18,7 @@ static unsigned ticks_visible;
 void draw_wifi_widget( unsigned force, int x, int y ){
 	if(force){
 		// background for all widgets is cleared by draw_window()
+		wifi_widget_page = primary_widgets;
 	} else if(hw_changes & HW_WIFI || svc_changes & SVC_WIFI){
 		// widget background
 		x_set_color(bg_color);
@@ -43,6 +44,8 @@ void draw_wifi_widget( unsigned force, int x, int y ){
 			draw_text(hw_wifi.address, 13, fg1_color, x+210, y+90, ALIGN_LEFT, ALIGN_BOTTOM, 0);
 	} else if(hw_wifi.state == WIFI_CONNECTING)
 		draw_text("C o n n e c t i n g ...", 16, red_status_color, x+60, y+70, ALIGN_LEFT, ALIGN_TOP, 0);
+	else if(hw_wifi.state == WIFI_DISCONNECTING)
+		draw_text("Disconnecting ...", 16, yellow_status_color, x+60, y+70, ALIGN_LEFT, ALIGN_TOP, 0);
 
 	ticks_visible = 0;
 }
