@@ -460,9 +460,9 @@ void window_map( ){
 
 	hw_refresh_cpu();
 	svc_refresh();
-	brightness_widget_page = volume_widget_page = battery_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = primary_widgets;
+	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = primary_widgets;
 	hw_refresh(); // query all values and then reset pages to prevent further queryies unless on current page
-	brightness_widget_page = volume_widget_page = battery_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = !primary_widgets;
+	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = !primary_widgets;
 
 	window.is_mapped = 1;
 
@@ -964,7 +964,7 @@ unsigned window_blank_events( ){
 		case ButtonRelease:
 			// close the blank window
 			window_close_blank();
-			notify_screen_unlocked();
+			if(cfg_tkactive_notifications) notify_screen_unlocked();
 			return 0; // get out of this loop or it will segfault
 		case KeyPress:
 			// ignore keys from the blank window
@@ -982,7 +982,7 @@ unsigned window_blank_events( ){
 			} else {
 				// close the blank window
 				window_close_blank();
-				notify_screen_unlocked();
+				if(cfg_tkactive_notifications) notify_screen_unlocked();
 				return 0; // get out of this loop or it will segfault
 			}
 			break;
